@@ -1,3 +1,4 @@
+import itertools
 import os
 import pickle
 import re
@@ -134,7 +135,7 @@ class MDSimulation():
                  atoms_to_freeze=None, atoms_to_restrain=None,
                  use_COM_restraint=False,
                  restraint_weight=None, constraints='HBonds',
-                 wrap_protein_ligand=False,
+                 wrap_all_chains=False,
                  state_out='sim.log',
                  implicit_solvent_model=None, hmr=False,
                  state_interval=None, progress_interval=None, traj_interval=None,
@@ -191,7 +192,7 @@ class MDSimulation():
         self.state_out = state_out
         self.atoms_to_restrain = atoms_to_restrain
         self.restraint_weight = restraint_weight
-        self.wrap_protein_ligand = wrap_protein_ligand
+        self.wrap_all_chains = wrap_all_chains
         self.implicit_solvent_model = implicit_solvent_model
         self.hmr = hmr
         self.run_time = run_time
@@ -390,10 +391,10 @@ class MDSimulation():
         if atom_selection2==None:
             atom_selection2 = select_atoms(self.parmed_structure,keyword_selection='protein')
 
-        virt_bond = mm.CustomCentroidBondForce(2, ' 0 * distance(g1,g2)')
-        virt_bond.addGroup(atom_selection1)
-        virt_bond.addGroup(atom_selection2)
-        virt_bond.addBond([0,1])
+        virt_bond = mm.CustomBondForce(' 0 * r')
+
+        print(atom_selection1,atom_selection2)
+        virt_bond.addBond(atom_selection1,atom_selection2)
         self.custom_forces['Virtual_Bond'] = self.system.addForce((virt_bond))
 
     def restrain_COM(self, atom_selection, COM_restraint_weight=20):
@@ -537,9 +538,16 @@ class MDSimulation():
         if self.atoms_to_freeze is not None:
             self.freeze_atom_selection(self.atoms_to_freeze)
 
-        if self.wrap_protein_ligand:
+        if self.wrap_all_chains:
             #if no atom selection is given this defaults to protein ligand
-            self.add_virtual_bond()
+            chains = [i for i in self.parmed_structure.topology.chains()]
+            atom_list = []
+            for i in chains:
+                #only get protein or ligand chains, the rest can image freely
+                if (next(i.residues()).name in aa_residues) or (next(i.residues()).name in lig_residues):
+                    atom_list.append(next(i.atoms()).index)
+            for i in itertools.combinations(atom_list,2):
+                self.add_virtual_bond(atom_selection1=i[0],atom_selection2=i[1])
 
         # get integrator
         if self.integrator_type not in ['Langevin', 'Verlet']:
